ProtocolParameters

Struct ProtocolParameters 

pub struct ProtocolParameters {
Show 33 fields pub deposit_per_item: Balance, pub deposit_per_byte: Balance, pub deposit_per_account: Balance, pub core_count: CoreIndex, pub min_turnaround_period: Slot, pub epoch_period: Slot, pub max_accumulate_gas: UnsignedGas, pub max_is_authorized_gas: UnsignedGas, pub max_refine_gas: UnsignedGas, pub block_gas_limit: UnsignedGas, pub recent_block_count: u16, pub max_work_items: u16, pub max_dependencies: u16, pub max_tickets_per_block: u16, pub max_lookup_anchor_age: Slot, pub tickets_attempts_number: u16, pub auth_window: u16, pub slot_period_sec: u16, pub auth_queue_len: u16, pub rotation_period: u16, pub max_extrinsics: u16, pub availability_timeout: u16, pub val_count: ValIndex, pub max_authorizer_code_size: u32, pub max_input: u32, pub max_service_code_size: u32, pub basic_piece_len: u32, pub max_imports: u32, pub segment_piece_count: u32, pub max_report_elective_data: u32, pub transfer_memo_size: u32, pub max_exports: u32, pub epoch_tail_start: Slot,
}
Baseline parameters for the JAM protocol.

Fields

deposit_per_item: Balance

(Bi) The additional deposit required for each preimage or storage item in an account.

deposit_per_byte: Balance

(Bl) The additional deposit required for each byte of each storage item in an account and preimage of an account.

deposit_per_account: Balance

(Bs) The base deposit required to retain an account.

core_count: CoreIndex

(C) Number of JAM cores.

min_turnaround_period: Slot

(D) The period in timeslots after which an unreferenced preimage may be expunged.

epoch_period: Slot

(E) The epoch period, defined in number of slots.

max_accumulate_gas: UnsignedGas

(Ga) Maximum gas which may be used to Accumulate a single work-report.

max_is_authorized_gas: UnsignedGas

(Gi) Maximum gas which may be used to Authorize a single work-package.

max_refine_gas: UnsignedGas

(Gr) Maximum gas which may be used to Refine a single work-report.

block_gas_limit: UnsignedGas

(Gt) Maximum gas which can be processed in a single block.

recent_block_count: u16

(H) The number of blocks which are kept in the recent block cache.

max_work_items: u16

(I) Maximum number of Work Items in a Work Package.

max_dependencies: u16

(J) Maximum number of dependencies (total of prerequisites and SR lookup entries).

max_tickets_per_block: u16

(K) Max tickets allowed to be embedded in each block extrinsic.

max_lookup_anchor_age: Slot

(L) Maximum age, in blocks, that the lookup anchor may be, taken from the regular anchor.

tickets_attempts_number: u16

(N) The number of distinct tickets which may be created and submitted by each validator on each epoch.

auth_window: u16

(O) Number of items in the authorization window.

slot_period_sec: u16

(P) The period for each JAM time slot, defined in seconds.

auth_queue_len: u16

(Q) Number of authorizations in a queue allocated to a core.

rotation_period: u16

(R) The rotation period, defined in number of slots.

max_extrinsics: u16

(T) Maximum number of extrinsics in a Work Package.

availability_timeout: u16

(U) The period in timeslots after which reported but unavailable work may be replaced.

val_count: ValIndex

(V) Total number of validators. Must by divisible by guarantor group size (3).

max_authorizer_code_size: u32

(Wa) The maximum size of authorizer code (used by Is-Authorized procedure).

max_input: u32

(Wb) Maximum size of a Work Package together with all extrinsic data and imported segments.

max_service_code_size: u32

(Wc) The maximum size of service code (used by Refine/Accumulate/OnTransfer procedures).

basic_piece_len: u32

(We) Number of octets in a basic piece. Must be even and divide into segment length (4,104).

max_imports: u32

(Wm) Maximum number of imports in a Work Package.

segment_piece_count: u32

(Wp) The number of erasure-coded pieces in a segment.

max_report_elective_data: u32

(Wr) The maximum total size of all unbounded blobs in a work-report, in octets.

transfer_memo_size: u32

(Wt) The size of a transfer memo in octets. The size of a transfer memo in octets.

max_exports: u32

(Wx) Maximum number of exports in a Work Package.

epoch_tail_start: Slot

(Y) The length of the contest, defined in number of slots.

Implementations

Source

impl ProtocolParameters

pub const fn full() -> Self

pub const fn tiny() -> Self

pub fn get() -> Self

pub fn validate(&self) -> Result<(), &'static str>

pub fn apply(self) -> Result<(), &'static str>