RefineContext

Struct RefineContext 

pub struct RefineContext {
    pub anchor: HeaderHash,
    pub state_root: StateRootHash,
    pub beefy_root: MmrPeakHash,
    pub lookup_anchor: HeaderHash,
    pub lookup_anchor_slot: Slot,
    pub prerequisites: VecSet<WorkPackageHash>,
}
Various pieces of information helpful to contextualize the Refinement process.

Fields

anchor: HeaderHash

The most recent header hash of the chain when building. This must be no more than RECENT_BLOCKS blocks old when reported.

state_root: StateRootHash

Must be state root of block anchor. This is checked on-chain when reported.

beefy_root: MmrPeakHash

Must be Beefy root of block anchor. This is checked on-chain when reported.

lookup_anchor: HeaderHash

The hash of a header of a block which is final. Availability will not succeed unless a super-majority of validators have attested to this. Preimage lookups will be judged according to this block.

lookup_anchor_slot: Slot

The slot of lookup_anchor on the chain. This is checked in availability and the report’s package will not be made available without it being correct. This value must be at least anchor_slot + 14400.

prerequisites: VecSet<WorkPackageHash>

Hashes of Work Packages, the reports of which must be reported prior to this one. This is checked on-chain when reported.