pub trait Get<T> {
// Required method
fn get() -> T;
}Expand description
A trait for querying a single value from a type.
It is not required that the value is constant.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".